# Getting Started
### On this page
  * [Introduction to SAP LeanIX](https://help.sap.com/docs/leanix/ea/getting-started#introduction-to-sap-leanix)
  * [SAP LeanIX Products](https://help.sap.com/docs/leanix/ea/getting-started#sap-leanix-products)
  * [Key Concepts and Features](https://help.sap.com/docs/leanix/ea/getting-started#key-concepts-and-features)
  * [Who Uses SAP LeanIX](https://help.sap.com/docs/leanix/ea/getting-started#who-uses-sap-leanix)
  * [Resources](https://help.sap.com/docs/leanix/ea/getting-started#resources)


Introductory guide to begin your journey with SAP LeanIX.
The getting started section helps new users understand SAP LeanIX's enterprise architecture products. It covers key concepts, user interface, and essential features, giving you a foundational understanding of SAP LeanIX and its role in enterprise architecture management.
